==> react-stripe-elements-1.3.1.tgz: package/lib/components/Elements.test.js <==
'use strict';

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _enzyme = require('enzyme');

var _Elements = require('./Elements');

var _Elements2 = _interopRequireDefault(_Elements);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

describe('Elements', function () {
  var stripeMock = void 0;

  beforeEach(function () {
    stripeMock = {
      elements: jest.fn(function () {
        throw new Error('elements() should not be called twice in this test.');
      }).mockReturnValueOnce(true),
      createToken: jest.fn(),
      createSource: jest.fn()
    };
  });

  it('creates the context', function () {
    var syncContext = {
      tag: 'sync',
      stripe: stripeMock
    };
    var wrapper = (0, _enzyme.mount)(_react2.default.createElement(
      _Elements2.default,
      null,
      _react2.default.createElement('div', null)
    ), { context: syncContext });
    var childContext = wrapper.node.getChildContext();
    expect(Object.keys(childContext)).toEqual(['addElementsLoadListener', 'registerElement', 'unregisterElement', 'getRegisteredElements']);
  });

  it('with sync context: addElementsLoadListener returns the same elements instance ', function () {
    var syncContext = {
      tag: 'sync',
      stripe: stripeMock
    };
    var wrapper = (0, _enzyme.mount)(_react2.default.createElement(
      _Elements2.default,
      null,
      _react2.default.createElement('div', null)
    ), { context: syncContext });
    var childContext = wrapper.node.getChildContext();

    var mockCallback = jest.fn();
    childContext.addElementsLoadListener(mockCallback);
    expect(mockCallback).toHaveBeenCalledTimes(1);
    expect(mockCallback).toHaveBeenLastCalledWith(true);
    childContext.addElementsLoadListener(mockCallback);
    expect(mockCallback).toHaveBeenCalledTimes(2);
    expect(mockCallback).toHaveBeenCalledWith(true);
  });

  it('with async context: addElementsLoadListener returns the same elements instance ', function () {
    var asyncContext = {
      tag: 'async',
      addStripeLoadListener: jest.fn(function (callback) {
        return callback(stripeMock);
      })
    };
    var wrapper = (0, _enzyme.mount)(_react2.default.createElement(
      _Elements2.default,
      null,
      _react2.default.createElement('div', null)
    ), { context: asyncContext });
    var childContext = wrapper.node.getChildContext();

    var mockCallback = jest.fn();
    childContext.addElementsLoadListener(mockCallback);
    expect(mockCallback).toHaveBeenCalledTimes(1);
    expect(mockCallback).toHaveBeenLastCalledWith(true);
    childContext.addElementsLoadListener(mockCallback);
    expect(mockCallback).toHaveBeenCalledTimes(2);
    expect(mockCallback).toHaveBeenCalledWith(true);
  });
}); // @noflow

==> react-stripe-elements-4.0.2.tgz: package/lib/components/Elements.test.js <==
'use strict';

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _enzyme = require('enzyme');

var _Elements = require('./Elements');

var _Elements2 = _interopRequireDefault(_Elements);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

describe('Elements', function () {
  var stripeMock = void 0;

  beforeEach(function () {
    stripeMock = {
      elements: jest.fn(function () {
        throw new Error('elements() should not be called twice in this test.');
      }).mockReturnValueOnce(true),
      createToken: jest.fn(),
      createSource: jest.fn(),
      createPaymentMethod: jest.fn()
    };
  });

  it('creates the context', function () {
    var syncContext = {
      tag: 'sync',
      stripe: stripeMock
    };
    var wrapper = (0, _enzyme.mount)(_react2.default.createElement(
      _Elements2.default,
      null,
      _react2.default.createElement('div', null)
    ), { context: syncContext });
    var childContext = wrapper.node.getChildContext();
    expect(Object.keys(childContext)).toEqual(['addElementsLoadListener', 'registerElement', 'unregisterElement', 'getRegisteredElements']);
  });

  it('with sync context: addElementsLoadListener returns the same elements instance ', function () {
    var syncContext = {
      tag: 'sync',
      stripe: stripeMock
    };
    var wrapper = (0, _enzyme.mount)(_react2.default.createElement(
      _Elements2.default,
      null,
      _react2.default.createElement('div', null)
    ), { context: syncContext });
    var childContext = wrapper.node.getChildContext();

    var mockCallback = jest.fn();
    childContext.addElementsLoadListener(mockCallback);
    expect(mockCallback).toHaveBeenCalledTimes(1);
    expect(mockCallback).toHaveBeenLastCalledWith(true);
    childContext.addElementsLoadListener(mockCallback);
    expect(mockCallback).toHaveBeenCalledTimes(2);
    expect(mockCallback).toHaveBeenCalledWith(true);
  });

  it('with async context: addElementsLoadListener returns the same elements instance ', function () {
    var asyncContext = {
      tag: 'async',
      addStripeLoadListener: jest.fn(function (callback) {
        return setTimeout(function () {
          return callback(stripeMock);
        }, 0);
      })
    };
    var wrapper = (0, _enzyme.mount)(_react2.default.createElement(
      _Elements2.default,
      null,
      _react2.default.createElement('div', null)
    ), { context: asyncContext });
    var childContext = wrapper.node.getChildContext();

    var a = new Promise(function (resolve) {
      return childContext.addElementsLoadListener(function (first) {
        expect(first).toEqual(true);
        resolve();
      });
    });
    var b = new Promise(function (resolve) {
      return childContext.addElementsLoadListener(function (second) {
        expect(second).toEqual(true);
        resolve();
      });
    });
    return Promise.all([a, b]);
  });
}); // @noflow
